pub(crate) struct JsonExprPlanner;Expand description
Rewrites JSON-aware SQL expressions into DataFusion expressions.
This planner handles three cases:
- Rewrites compound identifiers on JSON extension columns into
json_getfunction. For example,select a.b.c=>select json_get(a, "b.c"). - Extends a JSON path with list indexes and fields following an index.
For example,
select a.b[0].c=>select json_get(a, "b[0][\"c\"]"). - Pushes an “expected type” argument into the
json_getfunction when it participates in a binary operator. So thatjson_getknows the wanted data type when dealing with variant JSON values. For example,select json_get(a, "b.c") + 1=>select json_get(a, "b.c", NULL::Int64) + 1. - Infers the expected type from scalar, aggregate, and window function signatures.
For example,
select abs(a.b.c)=>select abs(json_get(a, "b.c", NULL::Float64)).